@@ -12,15 +12,15 @@ static inline bool samenum(const float x, const float y)
   return (fabsf(x-y) < EPS);
 }
 
-static inline bool isSym(const len_t n, const float *const restrict x)
+static inline bool isSym(const float_len_t n, const float *const restrict x)
 {
-  for (len_t j=0; j<n; j+=BLOCKSIZE)
+  for (float_len_t j=0; j<n; j+=BLOCKSIZE)
   {
-    for (len_t i=j; i<n; i+=BLOCKSIZE)
+    for (float_len_t i=j; i<n; i+=BLOCKSIZE)
     {
-      for (len_t col=j; col<j+BLOCKSIZE && col<n; ++col)
+      for (float_len_t col=j; col<j+BLOCKSIZE && col<n; ++col)
       {
-        for (len_t row=i; row<i+BLOCKSIZE && row<n; ++row)
+        for (float_len_t row=i; row<i+BLOCKSIZE && row<n; ++row)
         {
           const bool check = samenum(x[col + n*row], x[row + n*col]);
           if (!check)
@@ -38,8 +38,8 @@ static inline bool isSym(const len_t n, const float *const restrict x)
 SEXP R_isSymmetric_spm(SEXP x)
 {
   SEXP ret;
-  const len_t m = NROWS(x);
-  const len_t n = NCOLS(x);
+  const float_len_t m = NROWS(x);
+  const float_len_t n = NCOLS(x);
   
   PROTECT(ret = allocVector(LGLSXP, 1));
   
